@@ -78,9 +78,16 @@ def get_tests(function):
     """
     return [
         x for x in get_callable_cells(function)
-        if x.func_code.co_varnames[0] in ["user", "u"]
+        if getattr(x, 'func_code', None) and x.func_code.co_varnames[0] in ["user", "u"]
     ]
 
+def resolve_path(path, context):
+    current = context
+    for obj in path.split('.'):
+        current = current[obj]
+    
+    return current
+    
 class MenuItem(template.Node):
     """
     The template node for generating a menu item.
@@ -96,15 +103,10 @@ class MenuItem(template.Node):
         """
         super(MenuItem, self).__init__()
         self.template_file = template_file or 'menu/item.html'
-        url = url.strip('\'"')
-        if url.startswith('url:'):
-            self.url = reverse(url[4:], args=[])
-        else:
-            self.url = url
-            
-        self.text = text.strip('\'"')
+        self.url = url
+        self.text = text
         self.classes = classes or ""
-        self.nodelist = False
+        self.nodelist = []
         
     def render(self, context):
         """
@@ -114,12 +116,31 @@ class MenuItem(template.Node):
         Basically, we need `request` to be in the context, so we can access
         the logged in user.
         """
-        if self not in context.render_context:
-            context.render_context[self] = {
-                'url': self.url,
-                'text': self.text,
-                'classes': self.classes
-            }
+        if self.url[0] in "\"'":
+            url = self.url.strip("'\"")
+        else:
+            url = self.url
+            
+        if url.startswith('url:'):
+            url = reverse(url[4:])
+        else:
+            url = resolve_path(url, context)
+        
+        if self.text[0] in "\"'":
+            text = self.text.strip("\"'")
+        else:
+            text = resolve_path(self.text, context)
+
+        if not self.classes or self.classes[0] in "\"'":
+            classes = self.classes.strip("\"'")
+        else:
+            classes = resolve_path(self.classes, context)
+        
+        context.render_context[self] = {
+            'url': url,
+            'text': text,
+            'classes': classes
+        }
         
         local = dict(context.render_context[self])
         
@@ -189,21 +210,24 @@ class MenuItem(template.Node):
         return self.nodelist.render(new_context)
         
     
-def tested_menu_item(_parser, token):
+def base_menu_item(template="menu/item.html"):
     """
     The actual template tag.
     """
-    error_message = "'menu_item' tag requires at least 2, at most 3 arguments"
+    def inner(_parser, token):
+        error_message = "'menu_item' tag requires at least 2, at most 3 arguments"
     
-    try:
-        parts = token.split_contents()
-    except ValueError:
-        raise template.TemplateSyntaxError(error_message)
+        try:
+            parts = token.split_contents()
+        except ValueError:
+            raise template.TemplateSyntaxError(error_message)
     
-    if not (3 <= len(parts) <= 4):
-        raise template.TemplateSyntaxError(error_message)
+        if not (3 <= len(parts) <= 4):
+            raise template.TemplateSyntaxError(error_message)
     
-    # parts[0] is the name of the tag.
-    return MenuItem('menu/item.html', *parts[1:])
+        # parts[0] is the name of the tag.
+        return MenuItem(template, *parts[1:])
+    return inner
 
-register.tag('menu_item', tested_menu_item)
\ No newline at end of file
+register.tag('menu_item', base_menu_item())
+register.tag('li_menu_item', base_menu_item('menu/li-item.html'))
\ No newline at end of file
